/* libsvg-cairo - Render SVG documents using the cairo library
 *
 * Copyright  2002 USC/Information Sciences Institute
 *
 * Permission to use, copy, modify, distribute, and sell this software
 * and its documentation for any purpose is hereby granted without
 * fee, provided that the above copyright notice appear in all copies
 * and that both that copyright notice and this permission notice
 * appear in supporting documentation, and that the name of
 * Information Sciences Institute not be used in advertising or
 * publicity pertaining to distribution of the software without
 * specific, written prior permission.  Information Sciences Institute
 * makes no representations about the suitability of this software for
 * any purpose.  It is provided "as is" without express or implied
 * warranty.
 *
 * INFORMATION SCIENCES INSTITUTE DISCLAIMS ALL WARRANTIES WITH REGARD
 * TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL INFORMATION SCIENCES
 * INSTITUTE BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
 * DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA
 * OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 *
 * Author: Carl Worth <cworth@isi.edu>
 */

#ifndef SVG_CAIRO_H
#define SVG_CAIRO_H

#include <cairo.h>

#include <svg.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef enum svg_cairo_status {
    SVG_CAIRO_STATUS_SUCCESS = SVG_STATUS_SUCCESS,
    SVG_CAIRO_STATUS_NO_MEMORY = SVG_STATUS_NO_MEMORY,
    SVG_CAIRO_STATUS_IO_ERROR = SVG_STATUS_IO_ERROR,
    SVG_CAIRO_STATUS_FILE_NOT_FOUND = SVG_STATUS_FILE_NOT_FOUND,
    SVG_CAIRO_STATUS_INVALID_VALUE = SVG_STATUS_INVALID_VALUE,
    SVG_CAIRO_STATUS_INVALID_CALL = SVG_STATUS_INVALID_CALL,
    SVG_CAIRO_STATUS_PARSE_ERROR = SVG_STATUS_PARSE_ERROR
} svg_cairo_status_t;

typedef struct svg_cairo svg_cairo_t;

svg_cairo_status_t
svg_cairo_create (svg_cairo_t **svg_cairo);

svg_cairo_status_t
svg_cairo_destroy (svg_cairo_t *svg_cairo);

svg_cairo_status_t
svg_cairo_parse (svg_cairo_t *svg_cairo, const char *filename);

svg_cairo_status_t
svg_cairo_parse_file (svg_cairo_t *svg_cairo, FILE *file);

svg_cairo_status_t
svg_cairo_parse_buffer (svg_cairo_t *svg_cairo, const char *buf, size_t count);

svg_cairo_status_t
svg_cairo_parse_chunk_begin (svg_cairo_t *svg_cairo);

svg_cairo_status_t
svg_cairo_parse_chunk       (svg_cairo_t *svg_cairo, const char *buf, size_t count);

svg_cairo_status_t
svg_cairo_parse_chunk_end   (svg_cairo_t *svg_cairo);

svg_cairo_status_t
svg_cairo_render (svg_cairo_t *svg_cairo, cairo_t *xrs);

/* XXX: Ugh... this inconsistent interface needs to be cleaned up. */
svg_cairo_status_t
svg_cairo_set_viewport_dimension (svg_cairo_t *svg_cairo, unsigned int width, unsigned int height);

void
svg_cairo_get_size (svg_cairo_t *svg_cairo, int *width, int *height);

#ifdef __cplusplus
}
#endif

#endif
